"""ANSI escape sequence constants for terminal input."""

# Arrow keys
UP = "\x1b[A"
DOWN = "\x1b[B"
RIGHT = "\x1b[C"
LEFT = "\x1b[D"

# Control keys
ENTER = "\r"
BACKSPACE = "\x7f"
DELETE = "\x1b[3~"
TAB = "\t"
ESCAPE = "\x1b"
CTRL_C = "\x03"
CTRL_D = "\x04"
